Client

Struct Client 

pub struct Client { /* private fields */ }
The Client is used for all interaction with Control Tower or Edge Enforcer instances. Use one of the login functions to create an instance.

Implementations

Source

impl Client

pub fn builder() -> ClientBuilder

Create a Client builder.

pub async fn token_is_expired(&self) -> bool

Returns true if the token has expired.

pub async fn token_expires(&self) -> DateTime<Utc>

pub async fn jwt_svid(&self) -> Option<String>

Returns the JWT SVID if exists.

pub async fn x509_svid(&self) -> Option<X509SVID>

pub async fn bearer_token(&self) -> String

Returns the login bearer token.

pub async fn get_json<T: DeserializeOwned>( &self, path: &str, query_params: Option<&[(&str, &str)]>, ) -> Result<T>

GET a json payload from the REST API.

pub async fn get_bytes( &self, path: &str, query_params: Option<&[(&str, &str)]>, ) -> Result<Bytes>

GET a bytes payload from the REST API.

pub async fn post_json(&self, path: &str, data: &Value) -> Result<Value>

POST arbitrary JSON to a path.

Panics

never.

pub async fn put<T: Into<Body> + Debug>( &self, path: &str, content_type: &str, data: T, ) -> Result<()>

PUT arbitrary data to a path.

pub async fn put_json(&self, path: &str, data: &Value) -> Result<Value>

PUT arbitrary JSON to a path.

Errors

crate::error::Error

pub async fn volga_open_producer( &self, producer_name: &str, topic: &str, on_no_exists: OnNoExists, ) -> Result<Producer>

Open a volga producer on a topic.

Errors

crate::error::Error

pub async fn volga_open_child_site_producer( &self, producer_name: &str, topic: &str, site: &str, on_no_exists: OnNoExists, ) -> Result<Producer>

Open a volga NAT producer on a topic in a site.

Errors

crate::error::Error

pub async fn volga_open_parent_site_producer( &self, producer_name: &str, topic: &str, on_no_exists: OnNoExists, ) -> Result<Producer>

Open a volga producer on a topic in the parent site.

Errors

crate::error::Error

pub async fn volga_open_consumer( &self, consumer_name: &str, topic: &str, options: Options<'_>, ) -> Result<Consumer>

Creates and opens a Volga consumer.

Errors

crate::error::Error

pub async fn volga_open_child_site_consumer( &self, consumer_name: &str, topic: &str, site: &str, options: Options<'_>, ) -> Result<Consumer>

Creates and opens a Volga consumer on a child site.

Errors

crate::error::Error

pub async fn volga_open_parent_site_consumer( &self, consumer_name: &str, topic: &str, options: Options<'_>, ) -> Result<Consumer>

Creates and opens a Volga consumer on the parent site.

Errors

crate::error::Error

pub async fn volga_query_topic(&self, query: Query) -> Result<QueryStream>

Opens a query stream.

Errors

crate::error::Error

pub async fn connect( &self, application: &str, service_instance: &str, site: &str, protocol: Protocol, port: u16, ip_address: Option<IpAddr>, ) -> Result<Connection>

Setup a connection to a remote container.

Errors

crate::error::Error