#[non_exhaustive]pub struct MessageMetadata<T> {
pub time: DateTime<Utc>,
pub mtime: u64,
pub seqno: u64,
pub remain: u64,
pub payload: T,
pub producer_name: Option<String>,
}Expand description
Metadata on the Volga message received in Consumer::consume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time: DateTime<Utc>Timestamp.
mtime: u64Milliseconds since epoch.
seqno: u64Sequence number.
remain: u64The number of remaining message the client has indicated it can handle, see the Consumer more function.
payload: TThe message payload.
producer_name: Option<String>Name of the producer.